@@ -6,10 +6,8 @@ import logging
 from uuid import UUID
 
 from grpc import RpcError
-from tabulate import tabulate
 
 from preseem import NetworkMetadataReference
-from preseem_protobuf.model.element_pb2 import ElementDiscovery, ElementStatus
 
 # STM-6039 Only allow the sync to run once at a time, to prevent duplicate
 # entities from being created.
@@ -28,6 +26,13 @@ class ElementRole:
     CPE_RADIO = UUID('c72115d3-daf9-43ae-9475-083d62eae74f')
 
 
+_package_field_map = {
+    'name': lambda x: x.name,
+    'download_rate': lambda x: x.download_rate or None,
+    'upload_rate': lambda x: x.upload_rate or None,
+}
+
+
 async def call_and_log_error(co):
     """Call a GRPC coroutine and log any errors from it."""
     try:
@@ -45,6 +50,66 @@ async def call_and_log_error(co):
     return None
 
 
+async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, createrpc,
+                        updaterpc, field_map, noact):
+    """
+    Function to sync python bss-sourced objects to model objects.
+    Pass in the model and the company_uuid and source we are working on.
+    - bss_objs is a dict {source_id -> obj) where obj is a python bss object.
+    - model_objs is a list of objects from the model.
+    - createrpc and updaterpc are the grpc update methods for the object.
+    - field_map is a dict of {model field name -> mapping func} where the mapping func
+      returns the value to sync from the bss object.
+    """
+    new_ids = set(bss_objs)
+    for mobj in model_objs:
+        if mobj.source != source:
+            continue  # ignore objects owned by other sources
+        bobj = bss_objs.get(mobj.source_id)
+        if bobj:
+            changes = []
+            mods = {}
+            new_ids.discard(mobj.source_id)
+            if mobj.inactive:
+                changes.append('reactivated')
+                mods['inactive'] = False
+            for f, m in field_map.items():
+                mval = getattr(mobj, f)
+                bval = m(bobj)
+                if mval != bval:
+                    changes.append(f'{f}: {mval} -> {bval}')
+                    mods[f] = bval
+            if mods:
+                logging.info('sync_preseem_model(%s): modify %s (%s)', source, mobj,
+                             ', '.join(changes))
+                await call_and_log_error(
+                    updaterpc(company_uuid=company_uuid, uuid=mobj.uuid, **mods))
+        else:
+            if not mobj.inactive:
+                logging.info("sync_preseem_model(%s): deactivate %s %s", source,
+                             type(mobj).__name__.lower(), UUID(bytes=mobj.uuid))
+                if not noact:
+                    await call_and_log_error(
+                        updaterpc(company_uuid=company_uuid,
+                                  uuid=mobj.uuid,
+                                  inactive=True))
+    for obj_id in new_ids:
+        bobj = bss_objs.get(obj_id)
+        if bobj:
+            logging.info('sync_preseem_model(%s): create %s', source, bobj)
+            if not noact:
+                mobj = await call_and_log_error(
+                    createrpc(company_uuid=company_uuid,
+                              source=source,
+                              source_id=bobj.id,
+                              **{f: m(bobj)
+                                 for f, m in field_map.items()}))
+                if mobj:
+                    uuid = UUID(bytes=mobj.uuid)
+                    logging.info('sync_preseem_model(%s): created %s "%s"', source,
+                                 type(mobj).__name__, uuid)
+
+
 async def sync_preseem_model(preseem_model,
                              company_uuid,
                              source,
@@ -122,7 +187,7 @@ async def sync_preseem_model(preseem_model,
         if dup_ids:
             logging.warning('sync_preseem_model(%s): duplicate IDs found: %s', source,
                             dup_ids)
-            raise ValueError(f'duplicate IDs found')
+            raise ValueError('duplicate IDs found')
 
         for site_name in new_sites:
             logging.info('sync_preseem_model(%s): create site "%s"', source, site_name)
@@ -202,82 +267,27 @@ async def sync_preseem_model(preseem_model,
                     await call_and_log_error(
                         preseem_model.Element.UpdateElementDiscovery(
                             company_uuid=company_uuid, uuid=disc_uuid, inactive=True))
-
         if packages is not None:
             assert isinstance(packages, dict)
-            new_package_ids = set(packages)
-            for mpkg in model_packages:
-                if mpkg.source != source:
-                    continue
-                bpkg = packages.get(mpkg.source_id)
-                if bpkg:
-                    if not isinstance(bpkg.name, str) or bpkg.name == '':
-                        raise ValueError('invalid string value for package name')
-                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int)
-                                               or bpkg.download_rate < 0):
-                        raise ValueError('invalid value for package down rate')
-                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int)
-                                             or bpkg.upload_rate < 0):
-                        raise ValueError('invalid value for package up rate')
-                    changes = []
-                    mods = {}
-                    new_package_ids.discard(mpkg.source_id)
-                    if mpkg.inactive:
-                        changes.append('reactivated')
-                        mods['inactive'] = False
-                    if mpkg.name != bpkg.name:
-                        changes.append(f'name: {mpkg.name} -> {bpkg.name}')
-                        mods['name'] = bpkg.name
-                    if mpkg.download_rate != (bpkg.download_rate or None):
-                        changes.append(
-                            f'download_rate: {mpkg.download_rate} -> {bpkg.download_rate}'
-                        )
-                        mods['download_rate'] = bpkg.download_rate or None
-                    if mpkg.upload_rate != (bpkg.upload_rate or None):
-                        changes.append(
-                            f'upload_rate: {mpkg.upload_rate} -> {bpkg.upload_rate}')
-                        mods['upload_rate'] = bpkg.upload_rate or None
-                    if mods:
-                        logging.info('sync_packages(%s): modify %s (%s)', source, mpkg,
-                                     ', '.join(changes))
-                        await preseem_model.Package.Update(company_uuid=company_uuid,
-                                                           uuid=mpkg.uuid,
-                                                           **mods)
-                else:
-                    if not mpkg.inactive:
-                        logging.info("sync_preseem_model(%s): deactivate package %s",
-                                     source, UUID(bytes=mpkg.uuid))
-                        if not noact:
-                            await call_and_log_error(
-                                preseem_model.Package.Update(company_uuid=company_uuid,
-                                                             uuid=mpkg.uuid,
-                                                             inactive=True))
-            for pkg_id in new_package_ids:
-                bpkg = packages.get(pkg_id)
-                if bpkg:
-                    if not isinstance(bpkg.id, str) or bpkg.id == '':
-                        raise ValueError('invalid string value for package source_id')
-                    if not isinstance(bpkg.name, str) or bpkg.name == '':
-                        raise ValueError('invalid string value for package name')
-                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int)
-                                               or bpkg.download_rate < 0):
-                        raise ValueError('invalid value for package down rate')
-                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int)
-                                             or bpkg.upload_rate < 0):
-                        raise ValueError('invalid value for package up rate')
-                    logging.info('sync_preseem_model(%s): create %s', source, bpkg)
-                    if not noact:
-                        mpkg = await call_and_log_error(
-                            preseem_model.Package.Create(
-                                company_uuid=company_uuid,
-                                name=bpkg.name,
-                                source=source,
-                                source_id=bpkg.id,
-                                download_rate=bpkg.download_rate or None,
-                                upload_rate=bpkg.upload_rate or None))
-                        if mpkg:
-                            uuid = UUID(bytes=mpkg.uuid)
-                            logging.info('sync_preseem_model(%s): created Package "%s"',
-                                         source, uuid)
+            for pkg in packages.values():
+                if not isinstance(pkg.id, str) or pkg.id == '':
+                    raise ValueError('invalid string value for package source_id')
+                if not isinstance(pkg.name, str) or pkg.name == '':
+                    raise ValueError('invalid string value for package name')
+                if pkg.download_rate and (not isinstance(pkg.download_rate, int)
+                                          or pkg.download_rate < 0):
+                    raise ValueError('invalid value for package down rate')
+                if pkg.upload_rate and (not isinstance(pkg.upload_rate, int)
+                                        or pkg.upload_rate < 0):
+                    raise ValueError('invalid value for package up rate')
+            await _sync_objects(preseem_model,
+                                company_uuid,
+                                source,
+                                packages,
+                                model_packages,
+                                preseem_model.Package.Create,
+                                preseem_model.Package.Update,
+                                _package_field_map,
+                                noact=noact)
 
         return uuid_map
