@@ -26,9 +26,11 @@ import google.protobuf.timestamp_pb2
 
 import preseem_protobuf.model
 
+
 def _py_result(model, r, del_uuid):
     """Convert the result of a model operation to a python value,
        and update the object cache in the model."""
+
     def pb2py(pb, cls):
         """convert a protobuf to a python object."""
         fields = {}
@@ -51,7 +53,7 @@ def _py_result(model, r, del_uuid):
                         pbv = getattr(curpb, f, None) if curpb.HasField(f) else None
                     except ValueError:
                         pbv = getattr(curpb, f, None)
-                    if isinstance(pbv,  google.protobuf.timestamp_pb2.Timestamp):
+                    if isinstance(pbv, google.protobuf.timestamp_pb2.Timestamp):
                         pbv = pbv.ToNanoseconds() / 1000000000
                     if v != pbv:
                         pyv = getattr(curpy, f, None)
@@ -87,18 +89,20 @@ def _py_result(model, r, del_uuid):
             return
         return r
 
+
 def _pb_request(op, reqtype, **kwargs):
     """Setup a GRPC request protobuf for the given model operation."""
     req = reqtype()
     for k, v in kwargs.items():
         f = reqtype.DESCRIPTOR.fields_by_name[k]
-        if v is None and not (f.message_type and f.message_type.name.startswith('Nullable')):
+        if v is None and not (f.message_type
+                              and f.message_type.name.startswith('Nullable')):
             continue  # allow args to be passed a None to avoid setting them.
         if f.message_type:  # this is a nested message, not a simple type
             if f.message_type.name.startswith('Nullable'):
                 # special case where we have a OneOf for optional values
                 if v is None:
-                    setattr(getattr(req, k), 'null', 0) # NullValue.NULL_VALUE
+                    setattr(getattr(req, k), 'null', 0)  # NullValue.NULL_VALUE
                 else:
                     setattr(getattr(req, k), 'data', v)
             else:
@@ -119,19 +123,23 @@ def _pb_request(op, reqtype, **kwargs):
             setattr(req, k, v)
     return req
 
+
 async def _op(model, op, reqtype, delete=False, **kwargs):
     """Wrapper function to perform a GRPC operation on the model. (asyncio)"""
     req = _pb_request(op, reqtype, **kwargs)
-    company_uuid = kwargs.get('company_uuid') or (kwargs.get('uuid') if reqtype.__module__ == 'company_pb2' else None)
-    md = (('company-uuid', str(UUID(bytes=company_uuid))),) if company_uuid else None
+    company_uuid = kwargs.get('company_uuid') or (
+        kwargs.get('uuid') if reqtype.__module__ == 'company_pb2' else None)
+    md = (('company-uuid', str(UUID(bytes=company_uuid))), ) if company_uuid else None
     r = await model._client._grpc_op(op, req, collect_results=True, metadata=md)
     del_uuid = kwargs.get('uuid') if delete else None
     return _py_result(model, r, del_uuid)
 
+
 def _op_sync(model, op, reqtype, delete=False, **kwargs):
     """Wrapper function to perform a GRPC operation on the model. (non-asyncio)"""
-    company_uuid = kwargs.get('company_uuid') or (kwargs.get('uuid') if reqtype.__module__ == 'company_pb2' else None)
-    md = (('company-uuid', str(UUID(bytes=company_uuid))),) if company_uuid else None
+    company_uuid = kwargs.get('company_uuid') or (
+        kwargs.get('uuid') if reqtype.__module__ == 'company_pb2' else None)
+    md = (('company-uuid', str(UUID(bytes=company_uuid))), ) if company_uuid else None
     req = _pb_request(op, reqtype, **kwargs)
     r = op(req, metadata=md)
     try:
@@ -142,14 +150,19 @@ def _op_sync(model, op, reqtype, delete=False, **kwargs):
     del_uuid = kwargs.get('uuid') if delete else None
     return _py_result(model, r, del_uuid)
 
+
 # XXX once we require Python 3.7, this should be a dataclass.
 class BaseModelObject:
     """Base class for all pythonized model objects."""
+
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
 
     def __repr__(self):
-        attrs = {x: str(UUID(bytes=y)) if y and x.endswith('uuid') else y for x, y in self.__dict__.items()}
+        attrs = {
+            x: str(UUID(bytes=y)) if y and x.endswith('uuid') else y
+            for x, y in self.__dict__.items()
+        }
         return f'{type(self).__name__}({attrs})'
 
     def __eq__(self, other):
@@ -169,6 +182,7 @@ class BaseModelObject:
 
 class PreseemModel:
     """API to the Preseem Data Model."""
+
     def __init__(self, client, cache=False):
         """Initialize the model with a GRPC client."""
         self._client = client
@@ -196,7 +210,7 @@ class PreseemModel:
                 svcname = stubcls[:-11]  # trim "ServiceStub" from the name
 
                 # Create a new python class for this model object type
-                cls = type(svcname, (BaseModelObject,), {})
+                cls = type(svcname, (BaseModelObject, ), {})
                 setattr(self, svcname, cls)
                 self._types[svcname] = cls
 
@@ -204,16 +218,26 @@ class PreseemModel:
                 for sname, s in pmod.DESCRIPTOR.services_by_name.items():
                     for method in s.methods:
                         reqtype = getattr(pmod, method.input_type.name)
-                        reqns = type(reqtype.DESCRIPTOR.name, (BaseModelObject,), {})
+                        reqns = type(reqtype.DESCRIPTOR.name, (BaseModelObject, ), {})
                         setattr(cls, reqtype.DESCRIPTOR.name, reqns)
-                        op=getattr(svcstub, method.name)
-                        setattr(cls, method.name, partial(wrapper, model=self, op=op, delete=method.name=='Delete', reqtype=reqtype))
-                        if method.output_type and not method.output_type.name.endswith('Response'):
+                        op = getattr(svcstub, method.name)
+                        setattr(
+                            cls, method.name,
+                            partial(wrapper,
+                                    model=self,
+                                    op=op,
+                                    delete=method.name == 'Delete',
+                                    reqtype=reqtype))
+                        if method.output_type and not method.output_type.name.endswith(
+                                'Response'):
                             if method.output_type.name not in self._types:
-                                self._types[method.output_type.name] = type(method.output_type.name, (BaseModelObject,), {})
+                                self._types[method.output_type.name] = type(
+                                    method.output_type.name, (BaseModelObject, ), {})
                         for nt in reqtype.DESCRIPTOR.nested_types:
                             # Create a nested object class
-                            nc = type(nt.name, (BaseModelObject,), {f: None for f in nt.fields_by_name})
+                            nc = type(nt.name, (BaseModelObject, ),
+                                      {f: None
+                                       for f in nt.fields_by_name})
                             setattr(reqns, nt.name, nc)
 
     async def init(self):
